==> cscec5b-storecloud-api-3.0.1-20220818.092027-63-sources.jar: com/ejianc/business/storecloud/vo/WarehouseManageVO.java <==
package com.ejianc.business.storecloud.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

public class WarehouseManageVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目ID

    private Long storeId; // 仓库

    private Integer type;//1-移动端物资验收保存（只更新数量） 2-PC端物资验收提交（只更新金额）

    private Integer inOutFlag;// 出入库属性1入库2出库

    private List<WarehouseFlowVO> flowVOList = new ArrayList<>();

    private List<Long> delDetailIdList = new ArrayList<>();

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }

    public List<WarehouseFlowVO> getFlowVOList() {
        return flowVOList;
    }

    public void setFlowVOList(List<WarehouseFlowVO> flowVOList) {
        this.flowVOList = flowVOList;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getInOutFlag() {
        return inOutFlag;
    }

    public void setInOutFlag(Integer inOutFlag) {
        this.inOutFlag = inOutFlag;
    }

    public List<Long> getDelDetailIdList() {
        return delDetailIdList;
    }

    public void setDelDetailIdList(List<Long> delDetailIdList) {
        this.delDetailIdList = delDetailIdList;
    }
}

==> cscec5b-storecloud-api-3.0.1-20221125.105405-222-sources.jar: com/ejianc/business/storecloud/vo/WarehouseManageVO.java <==
package com.ejianc.business.storecloud.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

public class WarehouseManageVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long projectId; // 项目ID

    private Long storeId; // 仓库

    private Integer type;//1-保存或删除（只更新数量） 2-提交或撤回（只更新金额）

    private Integer inOutFlag;// 出入库属性1入库2出库

    private List<WarehouseFlowVO> flowVOList = new ArrayList<>();

    private List<Long> delDetailIdList = new ArrayList<>();

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }

    public List<WarehouseFlowVO> getFlowVOList() {
        return flowVOList;
    }

    public void setFlowVOList(List<WarehouseFlowVO> flowVOList) {
        this.flowVOList = flowVOList;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getInOutFlag() {
        return inOutFlag;
    }

    public void setInOutFlag(Integer inOutFlag) {
        this.inOutFlag = inOutFlag;
    }

    public List<Long> getDelDetailIdList() {
        return delDetailIdList;
    }

    public void setDelDetailIdList(List<Long> delDetailIdList) {
        this.delDetailIdList = delDetailIdList;
    }
}
